@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "imap4d.h"
 
@@ -104,6 +105,9 @@ imap4d_authenticate (struct imap4d_command *command, char *arg)
   if (!auth_type)
     return util_finish (command, RESP_BAD, "Too few arguments");
 
+  if (tls_required)
+    return util_finish (command, RESP_NO, "Command disabled: Use STARTTLS first");
+  
   adata.command = command;
   adata.auth_type = auth_type;
   adata.arg = sp;
@@ -127,7 +131,7 @@ imap4d_authenticate (struct imap4d_command *command, char *arg)
       /* FIXME: Check for errors.  */
       chdir (homedir);
       namespace_init (homedir);
-      syslog (LOG_INFO, _("User '%s' logged in"), adata.username);
+      syslog (LOG_INFO, _("User `%s' logged in"), adata.username);
       
       return util_finish (command, RESP_OK,
 			  "%s authentication successful", auth_type);
