@@ -1,19 +1,20 @@
-/* GNU mailutils - a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001 Free Software Foundation, Inc.
+/* GNU Mailutils -- a suite of utilities for electronic mail
+   Copyright (C) 1999, 2001, 2003, 2005 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
-   This program is distributed in the hope that it will be useful,
+   GNU Mailutils is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with GNU Mailutils; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "imap4d.h"
 
@@ -64,6 +65,9 @@ imap4d_select0 (struct imap4d_command *command, char *arg, int flags)
     {
       select_flags = flags;
       state = STATE_SEL;
+
+      imap4d_set_observer (mbox);
+      
       if ((status = imap4d_select_status ()) == 0)
 	{
 	  free (mailbox_name);
@@ -74,7 +78,7 @@ imap4d_select0 (struct imap4d_command *command, char *arg, int flags)
 	}
     }
   status = util_finish (command, RESP_NO, "Couldn't open %s, %s",
-			mailbox_name, mu_errstring (status));
+			mailbox_name, mu_strerror (status));
   free (mailbox_name);
   return status;
 }
