@@ -13,12 +13,13 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "imap4d.h"
 
 /*
- *
+ *  
  */
 
 typedef int (*status_funcp) __P ((mailbox_t));
