@@ -11,9 +11,10 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   You should have received a copy of the GNU Lesser General
+   Public License along with this library; if not, write to the
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA */
 
 #ifndef _MAILUTILS_FILTER_H
 #define _MAILUTILS_FILTER_H
@@ -55,7 +56,20 @@ extern filter_record_t base64_filter;
 extern filter_record_t binary_filter;
 extern filter_record_t bit8_filter;
 extern filter_record_t bit7_filter;
+extern filter_record_t rfc_2047_Q_filter;
 
+enum mu_iconv_fallback_mode {
+  mu_fallback_none,
+  mu_fallback_copy_pass,
+  mu_fallback_copy_octal
+};
+
+extern int filter_iconv_create (stream_t *s, stream_t transport,
+				const char *fromcode, const char *tocode,
+				int flags,
+				enum mu_iconv_fallback_mode fallback_mode);
+
+  
 #ifdef __cplusplus
 }
 #endif
