@@ -11,9 +11,10 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   You should have received a copy of the GNU Lesser General
+   Public License along with this library; if not, write to the
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA */
 
 #ifndef _MAILUTILS_HEADER_H
 #define _MAILUTILS_HEADER_H
@@ -67,6 +68,7 @@ extern "C" {
 #define MU_HEADER_FCC                       "Fcc"
 #define MU_HEADER_DELIVERY_DATE             "Delivery-date"
 #define MU_HEADER_ENVELOPE_TO               "Envelope-to"
+#define MU_HEADER_X_EXPIRE_TIMESTAMP        "X-Expire-Timestamp"
   
 /* Mime support header attribute */
 
