@@ -11,9 +11,10 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   You should have received a copy of the GNU Lesser General
+   Public License along with this library; if not, write to the
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA */
 
 #ifndef _MAILUTILS_MAILBOX_H
 #define _MAILUTILS_MAILBOX_H
@@ -78,6 +79,10 @@ extern int  mailbox_set_debug       __P ((mailbox_t, mu_debug_t));
 /* Events.  */
 extern int  mailbox_get_observable  __P ((mailbox_t, observable_t *));
 
+/* Locking */  
+extern int mailbox_lock __P ((mailbox_t mbox));
+extern int mailbox_unlock __P ((mailbox_t mbox));
+  
 #ifdef __cplusplus
 }
 #endif
