@@ -11,20 +11,16 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   You should have received a copy of the GNU Lesser General
+   Public License along with this library; if not, write to the
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA */
 
 #ifndef _MAILUTILS_MU_AUTH_H
 #define _MAILUTILS_MU_AUTH_H
 
 #include <mailutils/types.h>
 
-typedef int (*mu_auth_fp) __P((void *return_data,
-			       void *key,
-			       void *func_data,
-			       void *call_data));
-
 struct mu_auth_data {
   /* These are from struct passwd */
   char    *name;       /* user name */
@@ -39,6 +35,11 @@ struct mu_auth_data {
   int     change_uid;
 };
 
+typedef int (*mu_auth_fp) __P((struct mu_auth_data **data,
+			       const void *key,
+			       void *func_data,
+			       void *call_data));
+
 struct mu_auth_module {
   char           *name;
   struct argp    *argp;
@@ -50,8 +51,9 @@ struct mu_auth_module {
   void           *auth_by_uid_data;
 };
 
-extern int mu_auth_runlist __P((list_t flist, void *return_data,
-				void *key, void *data));
+extern int mu_auth_runlist __P((list_t flist,
+				struct mu_auth_data **return_data,
+				const void *key, void *data));
 extern struct mu_auth_data *
 mu_get_auth_by_name __P ((const char *username));
 
@@ -61,8 +63,8 @@ mu_get_auth_by_uid __P((uid_t uid));
 extern int
 mu_authenticate __P((struct mu_auth_data *auth_data, char *pass));
 
-extern int mu_auth_nosupport __P((void *return_data,
-				  void *key,
+extern int mu_auth_nosupport __P((struct mu_auth_data **return_data,
+				  const void *key,
 				  void *func_data,
 				  void *call_data));
 
