@@ -1,22 +1,22 @@
-/* GNU mailutils - a suite of utilities for electronic mail
+/* GNU Mailutils -- a suite of utilities for electronic mail
    Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Lesser General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
 
-   This program is distributed in the hope that it will be useful,
+   This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Lesser General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   You should have received a copy of the GNU Lesser General
+   Public License along with this library; if not, write to the
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA */
 
 #include "mu_scm.h"
-#include <mailutils/registrar.h>
 
 #ifndef _PATH_SENDMAIL
 # define _PATH_SENDMAIL "/usr/lib/sendmail"
@@ -63,6 +63,7 @@ struct format_record {
 static struct format_record format_table[] = {
   { "mbox", &mbox_record },
   { "mh",   &mh_record },
+  { "maildir", &maildir_record },
   { "pop",  &pop_record },
   { "imap", &imap_record },
   { "sendmail", &sendmail_record },
@@ -165,12 +166,10 @@ static struct
 void
 mu_scm_init ()
 {
-  char *defmailer;
   int i;
   list_t lst;
 
-  asprintf (&defmailer, "sendmail:%s", _PATH_SENDMAIL);
-  _mu_scm_mailer = scm_makfrom0str (defmailer);
+  _mu_scm_mailer = scm_makfrom0str ("sendmail:" _PATH_SENDMAIL);
   mu_set_variable ("mu-mailer", _mu_scm_mailer);
 
   _mu_scm_debug = scm_makenum(0);
