@@ -1,19 +1,20 @@
-/* GNU mailutils - a suite of utilities for electronic mail
+/* GNU Mailutils -- a suite of utilities for electronic mail
    Copyright (C) 1999, 2001 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
-   This program is distributed in the hope that it will be useful,
+   GNU Mailutils is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with GNU Mailutils; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "mail.h"
 
@@ -22,21 +23,22 @@
  * pre[serve] [msglist]
  */
 
+static int
+hold0 (msgset_t *mspec, message_t msg, void *data)
+{
+  attribute_t attr;
+
+  message_get_attribute (msg, &attr);
+  attribute_unset_userflag (attr, MAIL_ATTRIBUTE_MBOXED);
+
+  cursor = mspec->msg_part[0];
+  
+  return 0;
+}
+
 int
 mail_hold (int argc, char **argv)
 {
-  message_t msg;
-  attribute_t attr;
-
-  if (argc > 1)
-    return util_msglist_command (mail_hold, argc, argv, 1);
-  else
-    {
-      if (util_get_message (mbox, cursor, &msg, MSG_ALL))
-        return 1;
-
-      message_get_attribute (msg, &attr);
-      attribute_unset_userflag (attr, MAIL_ATTRIBUTE_MBOXED);
-    }
-  return 0;
+  return util_foreach_msg (argc, argv, MSG_ALL, hold0, NULL);
 }
+
