@@ -14,7 +14,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "mail.h"
 
@@ -259,6 +260,7 @@ static char *default_setup[] = {
   "unfold subject",
   "sender mail-followup-to reply-to from",
   "set nocmd",
+  "set metamail",
   
   /* Start in mail reading mode */
   "set mode=read",
@@ -546,9 +548,12 @@ mail_warranty (int argc ARG_UNUSED, char **argv ARG_UNUSED)
     "   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
     "   GNU General Public License for more details.\n"
     "\n"
-    "   You should have received a copy of the GNU General Public License\n"
-    "   along with GNU Mailutils; if not, write to the Free Software\n"
-    "   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA\n\n"),
+    "   You should have received a copy of the GNU General Public License along\n"
+    "   with GNU Mailutils; if not, write to the Free Software Foundation,\n"
+    "   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA\n"
+    "\n"
+    "\n"
+),
     ofile);
 
   return 0;
