@@ -1,19 +1,20 @@
-/* GNU mailutils - a suite of utilities for electronic mail
+/* GNU Mailutils -- a suite of utilities for electronic mail
    Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
-   This program is distributed in the hope that it will be useful,
+   GNU Mailutils is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with GNU Mailutils; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "mail.h"
 
@@ -37,9 +38,8 @@ static const char *with_defs[] =
 
 
 int
-mail_version (int argc, char **argv)
-{
-  (void)argc; (void)argv;
+mail_version (int argc ARG_UNUSED, char **argv ARG_UNUSED)
+{ 
   fprintf (ofile, "%s", argp_program_version);
   if (with_defs[0] != NULL)
     {
@@ -50,5 +50,6 @@ mail_version (int argc, char **argv)
       fprintf (ofile, " )");
     }
   fprintf (ofile, "\n");
+
   return 0;
 }
