@@ -11,9 +11,10 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   You should have received a copy of the GNU Lesser General
+   Public License along with this library; if not, write to the
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -710,7 +711,7 @@ header_get_field_name (header_t header, size_t num, char *buf,
     {
       /* save one for the null */
       --buflen;
-      len = (len > buflen) ? len : len;
+      len = (len > buflen) ? buflen : len;
       memcpy (buf, header->hdr[num].fn, len);
       buf[len] = '\0';
     }
