@@ -1,20 +1,20 @@
-/* GNU mailutils - a suite of utilities for electronic mail
+/* GNU Mailutils -- a suite of utilities for electronic mail
    Copyright (C) 2002 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Lesser General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Lesser General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
 
-   This program is distributed in the hope that it will be useful,
+   This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU Lesser General Public License for more details.
-
-   You should have received a copy of the GNU Lesser General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Lesser General Public License for more details.
 
+   You should have received a copy of the GNU Lesser General
+   Public License along with this library; if not, write to the
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -45,7 +45,7 @@
 
 /* System database */
 static int
-mu_auth_system (void *return_data, struct passwd *pw)
+mu_auth_system (struct mu_auth_data **return_data, const struct passwd *pw)
 {
   char *mailbox_name;
   int rc;
@@ -60,7 +60,7 @@ mu_auth_system (void *return_data, struct passwd *pw)
 
   sprintf (mailbox_name, "%s%s", mu_path_maildir, pw->pw_name);
   
-  rc = mu_auth_data_alloc ((struct mu_auth_data **) return_data,
+  rc = mu_auth_data_alloc (return_data,
 			   pw->pw_name,
 			   pw->pw_passwd,
 			   pw->pw_uid,
@@ -75,8 +75,10 @@ mu_auth_system (void *return_data, struct passwd *pw)
 }
 
 int
-mu_auth_system_by_name (void *return_data, void *key,
-			void *unused_func_data, void *unused_call_data)
+mu_auth_system_by_name (struct mu_auth_data **return_data,
+			const void *key,
+			void *func_data ARG_UNUSED,
+			void *call_data ARG_UNUSED)
 {
   if (!key)
     {
@@ -87,8 +89,10 @@ mu_auth_system_by_name (void *return_data, void *key,
 }
 
 static int
-mu_auth_system_by_uid (void *return_data, void *key,
-		       void *unused_func_data, void *unused_call_data)
+mu_auth_system_by_uid (struct mu_auth_data **return_data,
+		       const void *key,
+		       void *func_data ARG_UNUSED,
+		       void *call_data ARG_UNUSED)
 {
   if (!key)
     {
@@ -99,12 +103,12 @@ mu_auth_system_by_uid (void *return_data, void *key,
 }
 
 static int
-mu_authenticate_generic (void *ignored_return_data,
-			 void *key,
-			 void *ignored_func_data,
+mu_authenticate_generic (struct mu_auth_data **return_data ARG_UNUSED,
+			 const void *key,
+			 void *func_data ARG_UNUSED,
 			 void *call_data)
 {
-  struct mu_auth_data *auth_data = key;
+  const struct mu_auth_data *auth_data = key;
   char *pass = call_data;
 
   return !auth_data
@@ -114,12 +118,12 @@ mu_authenticate_generic (void *ignored_return_data,
 
 /* Called only if generic fails */
 static int
-mu_authenticate_system (void *ignored_return_data,
-			void *key,
-			void *ignored_func_data,
+mu_authenticate_system (struct mu_auth_data **return_data ARG_UNUSED,
+			const void *key,
+			void *func_data ARG_UNUSED,
 			void *call_data)
 {
-  struct mu_auth_data *auth_data = key;
+  const struct mu_auth_data *auth_data = key;
   char *pass = call_data;
 
 #ifdef HAVE_SHADOW_H
