@@ -13,15 +13,18 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 /* MH rmm command */
 
 #include <mh.h>
 
 const char *program_version = "rmm (" PACKAGE_STRING ")";
-static char doc[] = N_("GNU MH rmm\v"
-"Use -help to obtain the list of traditional MH options.");
+/* TRANSLATORS: Please, preserve the vertical tabulation (^K character)
+   in this message */
+static char doc[] = N_("GNU MH rmm\v\
+Use -help to obtain the list of traditional MH options.");
 static char args_doc[] = N_("[+folder] [msgs]");
 
 /* GNU options */
@@ -77,7 +80,7 @@ main (int argc, char **argv)
   mu_init_nls ();
 
   mu_argp_init (program_version, NULL);
-  mh_argp_parse (argc, argv, 0, options, mh_option, args_doc, doc,
+  mh_argp_parse (&argc, &argv, 0, options, mh_option, args_doc, doc,
 		 opt_handler, NULL, &index);
 
   mbox = mh_open_folder (current_folder, 0);
