@@ -87,7 +87,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -192,7 +193,7 @@ static list_t rule_list;
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 119 "mimetypes.y"
+#line 120 "mimetypes.y"
 typedef union YYSTYPE {
   struct mimetypes_string string;
   list_t list;
@@ -200,7 +201,7 @@ typedef union YYSTYPE {
   struct node *node;
 } YYSTYPE;
 /* Line 191 of yacc.c.  */
-#line 203 "y.tab.c"
+#line 204 "y.tab.c"
 # define mimetypes_yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -212,7 +213,7 @@ typedef union YYSTYPE {
 
 
 /* Line 214 of yacc.c.  */
-#line 215 "y.tab.c"
+#line 216 "y.tab.c"
 
 #if ! defined (mimetypes_yyoverflow) || YYERROR_VERBOSE
 
@@ -386,9 +387,9 @@ static const mimetypes_yysigned_char mimetypes_yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const unsigned char mimetypes_yyrline[] =
 {
-       0,   128,   128,   131,   132,   135,   136,   145,   154,   155,
-     158,   164,   165,   169,   173,   179,   183,   187,   191,   194,
-     195,   198,   207,   213,   220
+       0,   129,   129,   132,   133,   136,   137,   146,   155,   156,
+     159,   165,   166,   170,   174,   180,   184,   188,   192,   195,
+     196,   199,   208,   214,   221
 };
 #endif
 
@@ -1108,7 +1109,7 @@ mimetypes_yyreduce:
   switch (mimetypes_yyn)
     {
         case 6:
-#line 137 "mimetypes.y"
+#line 138 "mimetypes.y"
     {
 	     struct rule_tab *p = mimetypes_malloc (sizeof (*p));
 	     if (!rule_list)
@@ -1120,7 +1121,7 @@ mimetypes_yyreduce:
     break;
 
   case 7:
-#line 146 "mimetypes.y"
+#line 147 "mimetypes.y"
     {
 	     if (arg_list)
 	       list_destroy (&arg_list);
@@ -1130,56 +1131,56 @@ mimetypes_yyreduce:
     break;
 
   case 10:
-#line 159 "mimetypes.y"
+#line 160 "mimetypes.y"
     {
 	     mimetypes_yyval.string = mimetypes_append_string2 (&mimetypes_yyvsp[-2].string, '/', &mimetypes_yyvsp[0].string);
 	   }
     break;
 
   case 12:
-#line 166 "mimetypes.y"
+#line 167 "mimetypes.y"
     {
 	     mimetypes_yyval.node = make_binary_node (L_OR, mimetypes_yyvsp[-1].node, mimetypes_yyvsp[0].node);
 	   }
     break;
 
   case 13:
-#line 170 "mimetypes.y"
+#line 171 "mimetypes.y"
     {
 	     mimetypes_yyval.node = make_binary_node (L_OR, mimetypes_yyvsp[-2].node, mimetypes_yyvsp[0].node);
 	   }
     break;
 
   case 14:
-#line 174 "mimetypes.y"
+#line 175 "mimetypes.y"
     {
 	     mimetypes_yyval.node = make_binary_node (L_AND, mimetypes_yyvsp[-2].node, mimetypes_yyvsp[0].node);
 	   }
     break;
 
   case 15:
-#line 180 "mimetypes.y"
+#line 181 "mimetypes.y"
     {
 	     mimetypes_yyval.node = make_negation_node (mimetypes_yyvsp[0].node);
 	   }
     break;
 
   case 16:
-#line 184 "mimetypes.y"
+#line 185 "mimetypes.y"
     {
 	     mimetypes_yyval.node = mimetypes_yyvsp[-1].node;
 	   }
     break;
 
   case 17:
-#line 188 "mimetypes.y"
+#line 189 "mimetypes.y"
     {
 	     mimetypes_yyval.node = make_suffix_node (&mimetypes_yyvsp[0].string);
 	   }
     break;
 
   case 21:
-#line 199 "mimetypes.y"
+#line 200 "mimetypes.y"
     {
 	     reset_lex ();
 	     mimetypes_yyval.node = make_functional_node (mimetypes_yyvsp[-2].string.ptr, mimetypes_yyvsp[-1].list);
@@ -1189,7 +1190,7 @@ mimetypes_yyreduce:
     break;
 
   case 22:
-#line 208 "mimetypes.y"
+#line 209 "mimetypes.y"
     {
 	     list_create (&arg_list);
 	     mimetypes_yyval.list = arg_list;
@@ -1198,7 +1199,7 @@ mimetypes_yyreduce:
     break;
 
   case 23:
-#line 214 "mimetypes.y"
+#line 215 "mimetypes.y"
     {
 	     list_append (mimetypes_yyvsp[-2].list, mimetypes_string_dup (&mimetypes_yyvsp[0].string));
 	     mimetypes_yyval.list = mimetypes_yyvsp[-2].list;
@@ -1209,7 +1210,7 @@ mimetypes_yyreduce:
     }
 
 /* Line 991 of yacc.c.  */
-#line 1212 "y.tab.c"
+#line 1213 "y.tab.c"
 
   mimetypes_yyvsp -= mimetypes_yylen;
   mimetypes_yyssp -= mimetypes_yylen;
@@ -1418,7 +1419,7 @@ mimetypes_yyreturn:
 }
 
 
-#line 223 "mimetypes.y"
+#line 224 "mimetypes.y"
 
 
 int
@@ -1564,7 +1565,7 @@ b_string (union argument *args)
   for (i = 0; i < str->len; i++)
     {
       int c = getc (mimeview_fp);
-      if (c == EOF || c != str->ptr[i])
+      if (c == EOF || (char)c != str->ptr[i])
 	return 0;
     }
   return 1;
